Struct
QmiMessageDmsSetOperatingModeInput
since: 1.0
Description [src]
struct QmiMessageDmsSetOperatingModeInput {
/* No available fields */
}
The QmiMessageDmsSetOperatingModeInput structure contains private data and should only be accessed
using the provided API.
Available since: 1.0
Constructors
qmi_message_dms_set_operating_mode_input_new
Allocates a new QmiMessageDmsSetOperatingModeInput.
since: 1.0
Instance methods
qmi_message_dms_set_operating_mode_input_ref
Atomically increments the reference count of self by one.
since: 1.0
qmi_message_dms_set_operating_mode_input_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.0