Struct
QmiMessageVoiceSetSupplementaryServiceOutput
since: 1.30
Description [src]
struct QmiMessageVoiceSetSupplementaryServiceOutput {
/* No available fields */
}
The QmiMessageVoiceSetSupplementaryServiceOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.30
Instance methods
qmi_message_voice_set_supplementary_service_output_get_result
Get the result of the QMI operation.
since: 1.30
qmi_message_voice_set_supplementary_service_output_get_service_status
Get the ‘Service Status’ field from self.
since: 1.30
qmi_message_voice_set_supplementary_service_output_ref
Atomically increments the reference count of self by one.
since: 1.30
qmi_message_voice_set_supplementary_service_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.30